==> sagcad_0.9.6.orig.tar.gz: sagcad-0.9.6/src/GridCopyDlg.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : GridCopyDlg.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2003/02/20
 *    Last                 : 2003/02/20
 * ====================================================================
 */
#ifndef __GRIDCOPYDLG_H__
#define __GRIDCOPYDLG_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 :   (struct #define etc)
 * -------------------------------------------------------
 */

struct _GRIDCOPY_DLG
{
	gdouble x_pitch;		/* ԥå */
	gdouble y_pitch;		/* ԥå */
	gint x_repeats;			/*  */
	gint y_repeats;			/*  */

	GtkWidget *x_pitch_entry;
	GtkWidget *y_pitch_entry;
	GtkWidget *x_repeats_entry;
	GtkWidget *y_repeats_entry;
	GtkWidget *parent;			
	GtkWidget *dialog;			
};
typedef struct _GRIDCOPY_DLG GRIDCOPY_DLG;



/* -------------------------------------------------------
 * 2 : ѿ (global)
 * -------------------------------------------------------
 */
#ifdef _GRIDCOPYDLG_
#define   GLOBAL
/*  */
#define   GLOBAL_VAL(v)  = (v)
#else
#define   GLOBAL	extern
/* ʬ̵ */
#define   GLOBAL_VAL(v)  /* */
#endif




#undef  GLOBAL
#undef  GLOBAL_VAL
#undef _GRIDCOPYDLG_



/* -------------------------------------------------------
 * 3 : ؿ (Function)
 * -------------------------------------------------------
 */
gint GridCopyDialog(GRIDCOPY_DLG *gridcopy_dlg);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __GRIDCOPYDLG_H__ */
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Source               : GridCopyDlg.h
 * ====================================================================
 */

==> sagcad-0.9.11.tar.gz: sagcad-0.9.11/src/GridCopyDlg.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : GridCopyDlg.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2003/02/20
 *    Last                 : 2007/10/24
 * ====================================================================
 */
#ifndef __GRIDCOPYDLG_H__
#define __GRIDCOPYDLG_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 : 前処理  (struct #define etc)
 * -------------------------------------------------------
 */

struct _GRIDCOPY_DLG
{
	gint value;
	gdouble x_pitch;		/* ピッチ　Ｘ */
	gdouble y_pitch;		/* ピッチ　Ｙ */
	gint x_repeats;			/* 回数　Ｘ */
	gint y_repeats;			/* 回数　Ｙ */

	GtkWidget *x_pitch_entry;
	GtkWidget *y_pitch_entry;
	GtkWidget *x_repeats_entry;
	GtkWidget *y_repeats_entry;
	GtkWidget *parent;			
	GtkWidget *dialog;			
};
typedef struct _GRIDCOPY_DLG GRIDCOPY_DLG;



/* -------------------------------------------------------
 * 2 : 外部変数 (global)
 * -------------------------------------------------------
 */
#ifdef _GRIDCOPYDLG_
#define   GLOBAL
/* 初期値設定 */
#define   GLOBAL_VAL(v)  = (v)
#else
#define   GLOBAL	extern
/* 初期値設定の代入部分を無くす */
#define   GLOBAL_VAL(v)  /* */
#endif




#undef  GLOBAL
#undef  GLOBAL_VAL
#undef _GRIDCOPYDLG_



/* -------------------------------------------------------
 * 3 : 外部関数 (Function)
 * -------------------------------------------------------
 */
gint GridCopyDialog(GRIDCOPY_DLG *gridcopy_dlg);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __GRIDCOPYDLG_H__ */
/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Source               : GridCopyDlg.h
 * ====================================================================
 */
